@@ -6,10 +6,56 @@ import time
 import glob
 import subprocess
 import re
-import bcolors
 import tempfile
 from functools import reduce
 
+
+class bcolors:
+    HEADER = '\033[95m'
+    OKBLUE = '\033[94m'
+    BLUE = '\033[94m'
+    OKGREEN = '\033[92m'
+    GREEN = '\033[92m'
+    PURPLE = '\033[0;35m'
+    LPURPLE = '\033[1;35m'
+    CYAN = '\033[0;36m'
+    MAGENTA = '\033[0;35m'
+    WARNING = '\033[93m'
+    YEL = '\033[93m'
+    FAIL = '\033[91m'
+    RED = '\033[91m'
+    ENDC = '\033[0m'
+    NC = '\033[0m'
+
+    def disable(self):
+        # may use to disable coloring, TODO: update to include all
+        self.HEADER = ''
+        self.OKBLUE = ''
+        self.OKGREEN = ''
+        self.WARNING = ''
+        self.FAIL = ''
+        self.ENDC = ''
+
+
+def render(*strings):
+    result = ""
+    for string in strings:
+        r = re.findall('\{(.*?)\}', string)
+        for c in r:
+            rc = c
+            if c[0] == "/":
+                rc = "ENDC"
+
+            try:
+                string = re.sub('\{' + c + '.*?\}', getattr(bcolors, rc), string)
+            except:
+                pass
+
+            string = re.sub('\{/\}', bcolors.NC, string)
+        result += string
+    return result
+
+
 excecution_root = None
 
 import logging
@@ -75,7 +121,7 @@ class par:
             return "%s=%s" % (self.name, str(self.value))
 
     def __repr__(self):
-        return bcolors.render("{BLUE}%s{/} == {YEL}%s{/} (%s)" % (self.name, repr(self.value), self.prompt))
+        return render("{BLUE}%s{/} == {YEL}%s{/} (%s)" % (self.name, repr(self.value), self.prompt))
 
 
 class parvalue:
@@ -286,12 +332,12 @@ class heatool:
         self.pars[name]=val
 
     def run(self,pretend=False,envup=None,env=None,strace=None,stdout=None,pfileschroot=True,quiet=False):
-        log(bcolors.render("{YEL} work dir to "+self.cwd+"{/}"))
+        log(render("{YEL} work dir to "+self.cwd+"{/}"))
         owd=get_cwd()
         os.chdir(self.cwd)
 
-        log(bcolors.render("{YEL}"+str([self.toolname]+self.pars.mkargs())+"{/}"))
-        log(bcolors.render("{YEL}"+" ".join([self.toolname]+self.pars.mkargs(quote=True))+"{/}"))
+        log(render("{YEL}"+str([self.toolname]+self.pars.mkargs())+"{/}"))
+        log(render("{YEL}"+" ".join([self.toolname]+self.pars.mkargs(quote=True))+"{/}"))
         if pretend:
             log("not actually running it")
             return
@@ -343,7 +389,7 @@ class heatool:
         return
 
     def __repr__(self):
-        return bcolors.render("{GREEN}%s{/}:\n"%self.toolname)+repr(self.pars)
+        return render("{GREEN}%s{/}:\n"%self.toolname)+repr(self.pars)
 
 
 class og_create(heatool):
